pub enum Error {
TopLevelGlob,
TopLevelGroup,
UseWithDiffAttr,
}Expand description
The error type returned if issues occur during UseBuilder operations
Variants
TopLevelGlob
A glob was found as the first entry in a use path - this is illegal Rust
TopLevelGroup
A group was found as the first entry in a use path - this is not supported
UseWithDiffAttr
The same use was found but with differing dual colon prefix, attributes, or visibility